AudioSpectrumData class

Audio spectrum data.

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

audioSpectrumData List<double>?
Audio spectrum data. The SDK divides the audio frequency into 256 bands and reports the energy value of each band through this parameter. The value range of each energy is -300, 1, in dBFS.
final
dataLength int?
The length of the audio spectrum data is 256.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited