ExternalVideoFrame class

External video frame.

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

alphaBuffer Uint8List?
Alpha channel data output by portrait segmentation algorithm. This data matches the size of the video frame. Each pixel value ranges from 0,255, where 0 represents background and 255 represents foreground (portrait). You can use this parameter to render the video background with various effects, such as transparency, solid color, image, video, etc. In custom video rendering scenarios, make sure both the input video frame and alphaBuffer are of Full Range type; other types may cause incorrect rendering of alpha data.
final
alphaStitchMode AlphaStitchMode?
When the video frame contains alpha channel data, sets the relative position of alphaBuffer to the video frame. See AlphaStitchMode.
final
buffer Uint8List?
Video buffer.
final
colorSpace → ColorSpace?
Color space property of the video frame. By default, Full Range and BT.709 standard configuration is applied. You can customize the setting based on your custom capture or rendering requirements. See VideoColorSpace.
final
cropBottom int?
This parameter only applies to raw video data.
final
cropLeft int?
This parameter only applies to raw video data.
final
cropRight int?
This parameter only applies to raw video data.
final
cropTop int?
This parameter only applies to raw video data.
final
d3d11Texture2d int?
This parameter only applies to video data in Windows Texture format. Represents a pointer to an object of type ID3D11Texture2D, which is used by the video frame.
final
eglType → EglContextType?
This parameter only applies to video data in Texture format. Refers to the Texture ID of the video frame.
final
fillAlphaBuffer bool?
For video data in BGRA or RGBA format, you can choose either method to set the alpha channel data: Automatically fill by setting this parameter to true. Set via the alphaBuffer parameter. This parameter only applies to video data in BGRA or RGBA format. Sets whether to extract the alpha channel data from the video frame and automatically fill it into alphaBuffer : true : Extract and fill alpha channel data. false : (default) Do not extract or fill alpha channel data.
final
format VideoPixelFormat?
Pixel format. See VideoPixelFormat.
final
hashCode int
The hash code for this object.
no setterinherited
height int?
Height of the input video frame.
final
matrix List<double>?
This parameter only applies to video data in Texture format. It is a 4x4 input transformation matrix, typically an identity matrix.
final
metadataBuffer Uint8List?
This parameter only applies to video data in Texture format. Refers to the data buffer of MetaData, default value is NULL.
final
metadataSize int?
This parameter only applies to video data in Texture format. Refers to the size of MetaData, default value is 0.
final
rotation int?
Field related to raw data. Specifies whether to rotate the input video frame clockwise. Options are 0, 90, 180, 270. Default is 0.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stride int?
Stride of the input video frame, in pixels (not bytes). For Texture, this refers to the width of the Texture.
final
textureId int?
This parameter only applies to video data in Texture format. It is a 4x4 input transformation matrix, typically an identity matrix.
final
textureSliceIndex int?
This parameter only applies to video data in Windows Texture format. Indicates the index of the ID3D11Texture2D texture object used by the video frame in the ID3D11Texture2D array.
final
timestamp int?
Timestamp of the input video frame, in milliseconds. Incorrect timestamps may cause frame drops or audio-video desynchronization.
final
type VideoBufferType?
Video type. See VideoBufferType.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited