RemoteAudioStats class
Audio statistics of the remote user.
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, includeIfNull: false)
Properties
- audioLossRate → int?
-
Audio frame loss rate (%) of the remote audio stream during the reporting interval.
final
- e2eDelay → int?
-
End-to-end audio delay (ms), i.e., the total time from when the remote user captures the audio to when the local user starts playing it.
final
- frozenRate → int?
-
Percentage (%) of the total freeze duration relative to the total valid audio duration. Valid audio duration refers to the time after the remote user joins the channel during which audio is not stopped or disabled.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- jitterBufferDelay → int?
-
Network delay from the audio receiver to the jitter buffer (ms). This parameter is not effective when the receiver is an audience member and audienceLatencyLevel in ClientRoleOptions is set to 1.
final
- mosValue → int?
-
During the reporting interval, the quality score of the received remote audio stream evaluated by Agora's real-time audio MOS (Mean Opinion Score) method. The return value ranges from
0,500. Divide the return value by 100 to get the MOS score in the range0,5, where a higher score indicates better audio quality. The subjective audio quality corresponding to the Agora real-time audio MOS score is as follows: MOS Score Audio Quality Greater than 4 Excellent audio quality, clear and smooth. 3.5 - 4 Good audio quality, occasional impairments, but still clear. 3 - 3.5 Fair audio quality, occasional stuttering, not very smooth, requires some effort to understand. 2.5 - 3 Poor audio quality, frequent stuttering, requires focus to understand. 2 - 2.5 Very poor audio quality, occasional noise, partial semantic loss, difficult to communicate. Less than 2 Extremely poor audio quality, frequent noise, significant semantic loss, communication impossible.final - networkTransportDelay → int?
-
Network delay from the audio sender to the receiver (ms).
final
- numChannels → int?
-
Number of audio channels.
final
- publishDuration → int?
-
Total publishing duration (ms) of the remote audio stream.
final
- qoeQuality → int?
-
Subjective experience quality of the local user when receiving remote audio.
final
- quality → int?
-
The quality of the audio stream sent by the remote user. See QualityType.
final
- qualityChangedReason → int?
-
Reason for poor subjective experience quality of the local user when receiving remote audio. See ExperiencePoorReason.
final
- receivedBitrate → int?
-
Average bitrate (Kbps) of the received remote audio stream during the reporting interval.
final
- receivedSampleRate → int?
-
Sampling rate of the received remote audio stream during the reporting interval.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalActiveTime → int?
-
Total valid time (ms) from the start of the audio call to this callback for the remote user.
Valid time excludes the total time the remote user was in a muted state.
final
- totalFrozenTime → int?
-
Total duration (ms) of audio freezes experienced by the remote user after joining the channel. An audio freeze is counted when the audio frame loss rate exceeds 4%.
final
- uid → int?
-
The user ID of the remote user.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited